pub fn csch_vec(x: &[f64]) -> Vec<f64>Expand description
csch_vec(x)
Hyperbolic Function
The csch_vec function calculates the hyperbolic cosecant value of each angle represented as a radian in the input iterator,
constructing a new vector from these results.
Examples
use mathlab::math::{csch_vec, INF_F64 as inf};
assert_eq!(csch_vec(&[0.0, 0.523598775598299, 3.141592653589793]), [inf, 1.825305574687952, 0.086589537530047]);End Fun Doc